 
<script setup name="Post">
import { facilityExaminePlanApi } from "@/api/examine/plan/index.js";
import setPostParams from "@/utils/searchParams.js";
import  user from "@/api/system/user";
import {sysDictData} from "../../../api/system/dict.js";
import facilityApi from "../../../api/facility/index.js";
const { proxy } = getCurrentInstance();

/**
 * 搜索
 */
const queryParams = ref({
    name:''
})
/** 搜索操作 */
function handleQuery() {
    getList({keywords:queryParams.value.name})
}

/**
 * 重置
 */
const resetQuery = () =>{
    queryParams.value.name = ''
    proxy.resetForm("queryRef");
    getList()
}
/** 列表 */
const tableData = ref([]); //初始化列表
const open = ref(false);
const loading = ref(true); //加载状态
const total = ref(0);
const title = ref("");

/** 表头 */
let  tableHeader = ref({
    planName: '计划名称',
    planTypeView: '计划类型',
    periodTypeView: '周期',
    facilityNames:'巡检设备列表',
    inspectUserName: '巡检人员',
    content:'巡检内容',
    beginTime: '计划开始日期',
    endTime: '计划结束日期',
    createTimeView:'创建时间',
      
   })
const pageParam = ref({
    total:0,
    limit:10,
    page:1,
})
/** 获取列表 */
const getList = async(val) => {
   loading.value = true;
    let postParam = setPostParams(val)
    let res = await facilityExaminePlanApi().search(postParam)
    loading.value = false;
   if(res.code == 200) {
         tableData.value = res.data.list;
         //枚举转换
         tableData.value.forEach((item)=>{
            item.stateName = item.state == 1 ? '启动' : '关闭'
         })
       pageParam.value.total = res.data.total;
       pageParam.value.page = res.data.page;
       pageParam.value.limit = res.data.limit;
   }
}
/**
 * 详情相关 
 * 
 * */
let openForm2 = ref(false)
let detailForm = ref({})
let detailTable = ref([])

/** 新增按钮操作 */
function handleAdd(){
   reset();
    open.value = true;
   title.value = "添加计划";
}
/** 修改按钮操作 */
function handleUpdate(row) {
    reset();
    Object.keys(form.value).forEach((key)=>{
      if(Object.keys(row).includes(key)){
          form.value[key] = row[key]
        }
    })
    //数据类型及格式转换
    dateRange.value.push(form.value.beginTime)
    dateRange.value.push(form.value.endTime)
    form.value.periodType = form.value.periodType.toString();
    form.value.planType = form.value.planType.toString();
    form.value.facilityIds =  form.value.facilityIds.split(',');
    form.value.id = row.id
    open.value = true;
    title.value = "修改计划";
}
/**
 * 表单相关
 */
const data = reactive({
    //表单
    form: {},
    //表单验证
    rules: {
        planName: [{ required: true, message: "计划名称不能为空", trigger: "blur" }],
        inspectUser: [{ required: true, message: "巡检人员不能为空", trigger: "blur" }]
    },
});

const { form, rules} = toRefs(data);
/**
 * 下拉框数据
 */
//获取枚举类型
const planTypeList = ref()
const periodTypeList = ref()
const getType = async(val) =>{
    let res = await sysDictData().searchType(val)
    if (res.code == 200) {
       return res.data
    }
}

//巡检人员
const userNameList = ref()
const getAccount = async() =>{
// 获取维修账号列表信息
    let res = await user().search({limit: 10000, status: 1,page:1})
    if (res.code == 200) {
        userNameList.value = res.data.list
    }
}
const checkedUser = (val) =>{
    userNameList.value.forEach( item =>{
        if(item.id == val){
            form.value.inspectUserName = item.nickName
        }
    })
}
//日期
const dateRange = ref([]);
async function changeDate(e){
    form.value.beginTime = e[0] + ' 00:00:00'
    form.value.endTime = e[1] + ' 23:59:59'
}
//巡检设备
const facilityList = ref()
const getFacility = async() =>{
    let res = await facilityApi().search({limit: 10000, status: 1,page:1})
    if (res.code == 200) {
        facilityList.value = res.data.list
    }
}

/** 提交表单按钮 */
function submitForm() {
   proxy.$refs["postRef"].validate(async valid => {
      if (valid) {
          form.value.facilityIds =  form.value.facilityIds.join()
         if(!form.value.id){
            let res = await facilityExaminePlanApi().create(form.value)
            if(res.code == 200) {
               proxy.$modal.msgSuccess("添加成功");
               open.value = false
               getList()
               reset()
            }
         }else{
            let res = await facilityExaminePlanApi().modify(form.value)
            if(res.code == 200) {
               proxy.$modal.msgSuccess("修改成功");
               open.value = false
               getList()
               reset()
            }
         }
      }
   });
}
/** 删除按钮操作 */
// function handleDelete(row) {
//    proxy.$modal.confirm('是否确认删除名称为"' + row.planName + '"的计划？')
//    .then(async() => {
//       let res = await facilityExaminePlanApi().remove(row.id)
//       if(res.code == 200) {
//          proxy.$modal.msgSuccess("删除成功");
//          open.value = false
//          getList()
//       }
//    }).catch(() => {});
// }
/** 关闭弹窗 */
function cancel() {
   open.value = false;
   openForm2.value = false;
   reset();
}
/** 表单重置 */
const reset = () => {
    form.value = {
        planName: '',
        planType: '',
        periodType: '',
        facilityIds:[],
        beginTime: '',
        endTime: '',
        inspectUser: '',
        inspectUserName: '',
        content: '',
        remark: '',
    }
   proxy.resetForm("postRef");
   open.value = false
   openForm2.value = false;
   getList();
}
onMounted(async () =>{

    planTypeList.value = await getType('inspect_type');
    periodTypeList.value = await getType('period_type');
    await getAccount()
    await getFacility()
    getList();
})

</script>
<template>
    <div class="app-container">
        <!--搜索框-->
        <el-form :model="queryParams" ref="queryRef" :inline="true">
            <el-form-item label="" prop="name">
               <el-input
                  v-model="queryParams.name"
                  placeholder="请输入计划名称"
                  clearable
                  style="width: 200px"
                  @keyup.enter="handleQuery"
               />
            </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
            <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-form>
        <!--操作按钮列-->
        <el-row :gutter="10">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
        </el-row>

        <!--表格及分页-->
        <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          ></el-table-column>
          <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
<!--                <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>-->
             </template>
          </el-table-column>
        </el-table>
        <pagination
          v-show="pageParam.total > 0"
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          @pagination="getList"
        />
        <!-- 添加表单弹窗 -->
        <el-dialog :title="title" v-model="open"  center>
          <el-form class="form-box" ref="postRef" :model="form" :rules="rules" label-width="90px">
             <el-form-item label="计划名称" prop="planName" >
                <el-input v-model="form.planName" placeholder="请输入设备名称" />
             </el-form-item>
             <el-form-item label="计划类型">
                <el-select v-model="form.planType" placeholder="请选择所计划类型">
                    <el-option
                    v-for="(item,index) in planTypeList"
                    :key="index"
                    :label="item.dictLabel"
                    :title="item.dictLabel"
                    :value="item.dictValue"
                    />
                </el-select>
             </el-form-item>
              <el-form-item class="checkbox-item"  label="巡检设备" prop="facilityIds">
                  <el-checkbox-group v-model="form.facilityIds">
                      <el-checkbox v-for="(item,index) in facilityList" :key="index" :label="item.facilityName" :value="item.id" size ="large" />
                  </el-checkbox-group>
              </el-form-item>
             <el-form-item label="计划周期">
                <el-select v-model="form.periodType" placeholder="请选择所计划类型">
                    <el-option
                    v-for="(item,index) in periodTypeList"
                    :key="index"
                    :label="item.dictLabel"
                    :title="item.dictLabel"
                    :value="item.dictValue"
                    />
                </el-select>
             </el-form-item>
             <el-form-item label="有效期">
                <el-date-picker
                    v-model="dateRange"
                    value-format="YYYY-MM-DD"
                    type="daterange"
                    start-placeholder="开始日期"
                    end-placeholder="结束日期"
                    @change="changeDate"
                ></el-date-picker>
            </el-form-item>
            <el-form-item label="巡检人员" prop="inspectUser">
                <el-select v-model="form.inspectUser" placeholder="请选择巡检人员" @change="checkedUser">
                    <el-option
                        v-for="(item,index) in userNameList"
                        :key="index"
                        :label="item.nickName"
                        :title="item.nickName"
                        :value="item.id"
                    />
                </el-select>
             </el-form-item>
              <el-form-item label="巡检内容" prop="content">
                  <el-input v-model="form.content" type="textarea" placeholder="请输入内容" />
              </el-form-item>
            <el-form-item label="备注" prop="remark">
                <el-input v-model="form.remark" type="textarea" placeholder="请输入内容" />
             </el-form-item>
              <el-form-item></el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
        </el-dialog>
    </div>
</template>
<style scoped lang="scss">
   .checkbox-item{
       width: 98%;
       .el-checkbox-group{
           background: rgba(241, 247, 253, 0.73);
           border-radius: 5px;
           border: 1px solid #dcdfe6;
           padding: 10px;
       }
   }
</style>